=======
History
=======

0.1.2 (2020-07-21)
------------------

- Remove duplicate rows before returning the dataframe in the ``json2geodf`` function.
- Add the missing dependecy

0.1.0 (2020-07-21)
------------------

- First release on PyPI.
